( cd usr/lib/apr-util-1 ; rm -rf apr_dbm_db.so )
( cd usr/lib/apr-util-1 ; ln -sf apr_dbm_db-1.so apr_dbm_db.so )
( cd usr/lib/apr-util-1 ; rm -rf apr_ldap.so )
( cd usr/lib/apr-util-1 ; ln -sf apr_ldap-1.so apr_ldap.so )
( cd usr/lib/apr-util-1 ; rm -rf apr_dbd_pgsql.so )
( cd usr/lib/apr-util-1 ; ln -sf apr_dbd_pgsql-1.so apr_dbd_pgsql.so )
( cd usr/lib/apr-util-1 ; rm -rf apr_dbd_sqlite3.so )
( cd usr/lib/apr-util-1 ; ln -sf apr_dbd_sqlite3-1.so apr_dbd_sqlite3.so )
( cd usr/lib ; rm -rf libaprutil-1.so.0 )
( cd usr/lib ; ln -sf libaprutil-1.so.0.3.9 libaprutil-1.so.0 )
( cd usr/lib ; rm -rf libaprutil-1.so )
( cd usr/lib ; ln -sf libaprutil-1.so.0.3.9 libaprutil-1.so )
